(function ($) {
  var OrderableMultistoreAdminSettings = {
    init: function () {
      var $multi_location_pages = jQuery("#locations_multi_location_pages");
      if ($multi_location_pages.length) {
        $multi_location_pages.attr('multiple', true);
        $multi_location_pages.select2({
          multiple: true
        });
      }
      $('.orderable-change-location-status__button').on('click', OrderableMultistoreAdminSettings.on_click_change_location_status);
    },
    /**
     * Handle on click change location status button.
     */
    on_click_change_location_status: function () {
      $(this).attr('disabled', true);
      $(this).siblings('.orderable-change-location-status__loading').removeClass('orderable-change-location-status__loading-hidden');
      var status = $(this).attr('data-change-to');
      var data = {
        action: 'update_location_status',
        _nonce_update_location_status: orderable_pro_multi_location_list_table_admin.nonce,
        location_id: $(this).attr('data-location-id'),
        status
      };
      switch (status) {
        case 'pause':
          OrderableMultistoreAdminSettings.pause_orders_for_today.bind(this)(data);
          break;
        case 'resume':
          OrderableMultistoreAdminSettings.resume_orders.bind(this)(data);
        default:
          break;
      }
    },
    /**
     * Fires after requesting to change the status of the location.
     */
    always_location_status_change: function () {
      $(this).attr('disabled', false);
      $(this).siblings('.orderable-change-location-status__loading').addClass('orderable-change-location-status__loading-hidden');
    },
    /**
     * Send a request to pause orders for today.
     *
     * @param {Object} data The data sent in the request.
     */
    pause_orders_for_today: function (data) {
      function on_success() {
        $(this).text(orderable_pro_multi_location_list_table_admin.text.resume);
        $(this).attr('data-change-to', 'resume');
        $(this).parents('tr').find('.orderable_store_status').text(orderable_pro_multi_location_list_table_admin.text.paused);
      }
      $.post(orderable_pro_multi_location_list_table_admin.ajax_url, data).done(on_success.bind(this)).always(OrderableMultistoreAdminSettings.always_location_status_change.bind(this));
    },
    /**
     * Send a request to resume orders.
     *
     * @param {Object} data The data sent in the request.
     */
    resume_orders: function (data) {
      function on_success(response) {
        var status = response.data && response.data.status || orderable_pro_multi_location_list_table_admin.text.open;
        $(this).text(orderable_pro_multi_location_list_table_admin.text.pause_order_for_today);
        $(this).attr('data-change-to', 'pause');
        $(this).parents('tr').find('.orderable_store_status').text(status);
      }
      $.post(orderable_pro_multi_location_list_table_admin.ajax_url, data).done(on_success.bind(this)).always(OrderableMultistoreAdminSettings.always_location_status_change.bind(this));
    }
  };
  $(document).ready(OrderableMultistoreAdminSettings.init);
})(jQuery);