<?php
/**
 * Module: Table Ordering Pro Checkout
 *
 * @package Orderable/Classes
 */

defined( 'ABSPATH' ) || exit;

/**
 * Table ordering checkout class.
 */
class Orderable_Table_Ordering_Pro_Checkout {
	/**
	 * Init.
	 */
	public static function run() {
		add_action( 'woocommerce_checkout_order_processed', array( __CLASS__, 'add_table_to_order' ), 10, 3 );
		add_action( 'woocommerce_review_order_after_order_total', array( __CLASS__, 'add_table_to_order_review' ) );
		add_filter( 'woocommerce_cart_needs_shipping', array( __CLASS__, 'cart_needs_shipping' ), 100 );
	}

	/**
	 * Add table to order on checkout.
	 *
	 * @param int      $order_id    Order ID.
	 * @param array    $posted_data Posted data.
	 * @param WC_Order $order       Order object.
	 */
	public static function add_table_to_order( $order_id, $posted_data, $order ) {
		$table = Orderable_Table_Ordering_Pro::get_table_from_cookie();

		if ( ! $table ) {
			return;
		}

		$order->add_meta_data( Orderable_Table_Ordering_Pro_Order::$key_table_id, $table->get_table_id() );
		$order->add_meta_data( Orderable_Table_Ordering_Pro_Order::$key_table, $table->get_title() );
		$order->add_meta_data( Orderable_Table_Ordering_Pro_Order::$key_table_post_id, $table->post_id );

		$order->save();

		Orderable_Table_Ordering_Pro::unset_table_id_cookie();
	}

	/**
	 * Add table to order review.
	 */
	public static function add_table_to_order_review() {
		$table = Orderable_Table_Ordering_Pro::get_table_from_cookie();

		if ( ! $table ) {
			return;
		} ?>
		<tr class="orderable-table">
			<th><?php esc_html_e( 'Table', 'orderable-pro' ); ?></th>
			<td><?php echo wp_kses_post( $table->get_title() ); ?></td>
		</tr>
		<?php
	}

	/**
	 * If table cookie exists, shipping is not required.
	 *
	 * @param bool $needs_shipping Needs shipping.
	 *
	 * @return bool
	 */
	public static function cart_needs_shipping( $needs_shipping ) {
		if ( Orderable_Table_Ordering_Pro::get_table_id_cookie() ) {
			return false;
		}

		return $needs_shipping;
	}
}