<?php

/**
 * Module: Table Ordering Pro - QR Codes.
 *
 * @package Orderable/Classes
 */
defined( 'ABSPATH' ) || exit;

/**
 * Tip module class.
 */
class Orderable_Table_Ordering_Pro_Qr {
	/**
	 * QR Generator API.
	 *
	 * @var string
	 */
	public static $api_url = 'https://chart.googleapis.com/chart?cht=qr&chs=300x300';

	/**
	 * Generate QR code.
	 *
	 * @param string $url     URL to encode as a QR code.
	 * @param int    $post_id Post ID.
	 *
	 * @return array|bool
	 */
	public static function generate_qr( $url, $post_id = 0 ) {
		$api_url = add_query_arg(
			array(
				'chl'  => rawurlencode( $url ),
				'type' => '.png',
			),
			self::$api_url
		);

		$file_name = sprintf( 'qr-code-%d.png', $post_id );

		$upload = Orderable_Helpers::add_to_media( $api_url, $post_id, $file_name );

		if ( ! $upload ) {
			return false;
		}

		return array(
			'attachment_id' => $upload,
			'api_url'       => $api_url,
		);
	}
}
