<?php
/**
 * Module: Timings Pro Checkout.
 *
 * @package Orderable/Classes
 */

defined( 'ABSPATH' ) || exit;

/**
 * Timings module class.
 */
class Orderable_Timings_Pro_Checkout {
	/**
	 * Init.
	 */
	public static function run() {
		add_action( 'woocommerce_checkout_process', array( __CLASS__, 'validate_checkout' ) );
		add_filter( 'orderable_checkout_data', array( __CLASS__, 'modify_checkout_data' ) );
	}

	/**
	 * Validate checkout fields.
	 *
	 * @throws Exception
	 */
	public static function validate_checkout() {
		$order_date = empty( $_POST['orderable_order_date'] ) ? '' : sanitize_text_field( wp_unslash( $_POST['orderable_order_date'] ) ); // phpcs:ignore WordPress.Security.NonceVerification
		$order_time = empty( $_POST['orderable_order_time'] ) ? '' : sanitize_text_field( wp_unslash( $_POST['orderable_order_time'] ) ); // phpcs:ignore WordPress.Security.NonceVerification

		if ( ! empty( $order_date ) && 'asap' !== $order_date ) {
			$location = new Orderable_Location_Single_Pro( Orderable_Location::get_selected_location() );

			$orders_remaining = $location->get_orders_remaining_for_date( $order_date );

			if ( $orders_remaining <= 0 ) {
				wc_add_notice( __( 'Sorry, the date you selected is no longer available. Please choose another.', 'orderable-pro' ), 'error' );
			}
		}

		if ( isset( $_POST['orderable_order_time'] ) && empty( $order_time ) ) {
			wc_add_notice( __( 'Please select an order time.', 'orderable-pro' ), 'error' );
		}
	}

	/**
	 * Process checkout fields.
	 *
	 * @param array $checkout_data Checkout data to save.
	 *
	 * @return mixed
	 */
	public static function modify_checkout_data( $checkout_data ) {
		$order_date = empty( $_POST['orderable_order_date'] ) ? '' : sanitize_text_field( wp_unslash( $_POST['orderable_order_date'] ) ); // phpcs:ignore WordPress.Security.NonceVerification
		$order_time = empty( $_POST['orderable_order_time'] ) ? '' : sanitize_text_field( wp_unslash( $_POST['orderable_order_time'] ) ); // phpcs:ignore WordPress.Security.NonceVerification
		$location   = Orderable_Location::get_selected_location();

		if ( $order_time && 'asap' !== $order_time ) {
			$hours       = substr( $order_time, 0, 2 );
			$minutes     = substr( $order_time, 2, 2 );
			$time_format = get_option( 'time_format' );

			$date_and_time = new DateTime( 'now', wp_timezone() );
			$date_and_time->setTimestamp( (int) $checkout_data['_orderable_order_timestamp']['value'] );
			$date_and_time->setTime( $hours, $minutes );

			$timestamp  = $date_and_time->getTimestamp();
			$order_time = $date_and_time->format( $time_format );

			$checkout_data['orderable_order_time'] = array(
				'save'  => true,
				'value' => $order_time,
			);

			$checkout_data['_orderable_order_timestamp'] = array(
				'save'  => true,
				'value' => $timestamp,
			);
		}

		if ( $order_time && 'asap' === $order_time ) {
			$dates = $location->get_service_dates();

			if ( ! $dates || ! $order_date ) {
				return;
			}

			$date = array_filter(
				$dates,
				function( $value ) use ( $order_date ) {
					return (int) $value['timestamp'] === (int) $order_date;
				},
				ARRAY_FILTER_USE_BOTH
			);

			if ( count( $date ) < 1 ) {
				return;
			}

			$date                     = array_values( $date )[0];
			$earliest_order_time      = array_key_first( $date['slots'] );
			$earliest_order_timestamp = array_values( $date['slots'] )[0]['timestamp'];

			$hours       = substr( $earliest_order_time, 0, 2 );
			$minutes     = substr( $earliest_order_time, 2, 2 );
			$time_format = get_option( 'time_format' );

			$date_and_time = new DateTime( 'now', wp_timezone() );
			$date_and_time->setTimestamp( (int) $earliest_order_timestamp );
			$date_and_time->setTime( $hours, $minutes );

			$timestamp           = $date_and_time->getTimestamp();
			$earliest_order_time = $date_and_time->format( $time_format );

			$checkout_data['orderable_order_time'] = array(
				'save'  => true,
				'value' => $earliest_order_time . esc_html__( ' (As soon as possible)', 'orderable-pro' ),
			);

			$checkout_data['_orderable_order_timestamp'] = array(
				'save'  => true,
				'value' => $timestamp,
			);
		}

		return $checkout_data;
	}
}